The ``rail.interactive`` module provides a set of functions that act as replacements for
the class-based system of running RAIL, which is now primarily used for Pipeline Mode.

These functions are generated at runtime from the RailStage classes and therefore do not
have viewable source code.

The docstrings given below are created from the RailStage classes and their primary
method (called the *entrypoint function*), and can be seen by users by inspecting the
function objects.
